import React, {useState, useEffect} from "react";
import {render} from "react-dom";
import styled from 'styled-components';
import Empty from "./empty/empty";
import PeriodDiv from "./period/period-div";
import Hr from "./project/hr";
import ProjectProgress from "./project/project-progress";
import TaskOverview from "./task/task-overview";


interface EWeekReportOverviewProps {
    hasProject?: boolean,
    hasTask?: boolean,
    periodStart?: string,
    periodEnd?: string,
    level: number,
    projectProgressNow: string,
    projectIncreaseCircle: string,
    projectDecrease: string,
    taskShouldFinishCount: number,
    taskRealFinishCount: number,
    taskOutDateCount: number,
    taskNotInProgress: number,
    taskOutDateForHumanCount: number,
    taskNotUpdateForHumanCount: number
}

/**
 *
 * @param {Boolean} [hasProject]-是否有项目不填写默认为false
 * @param {Boolean} [hasTask]-是否有任务不填写默认为true
 * @param {String} [periodStart]-周期开始时间不填写默认为空
 * @param {String} [periodEnd]-周期结束时间不填写默认为空
 * @param {number} level-风险级别
 * @param {String} projectDecrease-目标增长率下降
 * @param {String} projectIncreaseCircle-目标环比增长
 * @param {String} projectProgressNow-当前目标进度
 * @param {Number} taskNotInProgress-本周无进展量
 * @param {Number} taskOutDateCount-过期未完成量
 * @param {Number} taskOutDateForHumanCount-过期未完成任务的人数
 * @param {Number} taskRealFinishCount-实际完成量
 * @param {Number} taskShouldFinishCount-计划执行任务量
 * @param {Number} taskNotUpdateForHumanCount-未更新任务进展的人数
 * @constructor
 * @return React.Component
 */
function EWeekReportOverview({
                                 hasProject = false,
                                 hasTask = false,
                                 periodStart = '',
                                 periodEnd = '',
                                 level,
                                 projectDecrease,
                                 projectIncreaseCircle,
                                 projectProgressNow,
                                 taskNotInProgress,
                                 taskOutDateCount,
                                 taskOutDateForHumanCount,
                                 taskRealFinishCount,
                                 taskShouldFinishCount,
                                 taskNotUpdateForHumanCount
                             }: EWeekReportOverviewProps) {
    const hasNothing = !hasTask && !hasProject;
    const Div = styled.div`
        width: 1124px;
        height: ${hasTask ? '192px' : '118px'};
        background: #FFFFFF;
        border: 1px solid #F0F2F5;
        border-radius: 2px;
    `;

    return hasNothing ? <Empty/> :
        <Div>
            <PeriodDiv periodStart={periodStart} periodEnd={periodEnd || ''} level={level}/>
            <Hr/>
            <ProjectProgress hasTask={hasTask}
                             projectProgressNow={projectProgressNow}
                             projectIncreaseCircle={projectIncreaseCircle}
                             projectDecrease={projectDecrease}/>
            <TaskOverview taskNotUpdateForHumanCount={taskNotUpdateForHumanCount}
                          taskOutDateForHumanCount={taskOutDateForHumanCount}
                          taskNotInProgress={taskNotInProgress}
                          taskOutDateCount={taskOutDateCount}
                          taskRealFinishCount={taskRealFinishCount}
                          taskShouldFinishCount={taskShouldFinishCount}
                          hasTask={hasTask}/>
        </Div>
}
export default EWeekReportOverview;
// render(<EWeekReportOverview hasTask
//                             hasProject
//                             periodStart={'2019/10/01'}
//                             periodEnd={'2019/10/07'}
//                             level={1}
//                             projectProgressNow={'30%'}
//                             projectIncreaseCircle={'20%'}
//                             projectDecrease={'0'}
//                             taskShouldFinishCount={22}
//                             taskRealFinishCount={18}
//                             taskOutDateCount={3}
//                             taskNotInProgress={10}
//                             taskOutDateForHumanCount={10}
//                             taskNotUpdateForHumanCount={3}
//     />,
//     document.getElementsByTagName('body')[0]);

//E周报总览组件，所需参数如下
/**
 * hasProject: boolean 是否有项目情况 默认为false(非必填)
 * hasTask: boolean 是否有任务情况 默认为false(非必填)
 * periodStart: string 周期开始日期 当不传入该参数时表示没有任务也没有项目 默认为''(非必填)
 * periodStart: string 周期结束日期 当不传入该参数时表示没有任务也没有项目 默认为''(非必填)
 * level: number 危险级别 0是目标没有风险,1是目标已有风险 必填项
 * E周报项目选项的配置项
 * projectProgressNow: string 当前目标进度
 * projectIncreaseCircle: string 环比增长
 * projectDecrease: string 增长率
 * E周报任务选项的配置项
 * taskShouldFinishCount: number 本周应执行任务量
 * taskRealFinishCount: number 实际完成量
 * taskOutDateCount: number 过期未完成量
 * taskNotInProgress: number 本周无进展量
 * taskOutDateForHumanCount: number 过期未完成任务的人数
 * taskNotUpdateForHumanCount: number 未更新任务进展的人数
 */